@@ -11,12 +11,14 @@ class Debiai_model:
     A Debiai project model
     """
 
-    def __init__(self, project: 'Debiai_project', name: str, id: str):
+    def __init__(self, project: "Debiai_project", name: str, id: str):
         self.project = project
         self.name = name
         self.id = id
 
-    def add_results_dict(self, results: dict, expected_results_order: List[str] = None) -> bool:
+    def add_results_dict(
+        self, results: dict, expected_results_order: List[str] = None
+    ) -> bool:
         """
         Add a result to the model from a dict.
         The tree allow the user to specify to what sample he created the result
@@ -28,7 +30,8 @@ class Debiai_model:
 
         if self.project.expected_results is None:
             raise ValueError(
-                "The project expected results need to be specified before adding results")
+                "The project expected results need to be specified before adding results"
+            )
 
         if type(results) != dict:
             raise ValueError("Results must be of type dict")
@@ -36,8 +39,11 @@ class Debiai_model:
         if expected_results_order is not None:
             for expected_result in self.project.expected_results:
                 if expected_result["name"] not in expected_results_order:
-                    raise ValueError("The expected result '" + expected_result["name"] +
-                                     "' is missing from the expected_results_order Array")
+                    raise ValueError(
+                        "The expected result '"
+                        + expected_result["name"]
+                        + "' is missing from the expected_results_order Array"
+                    )
 
             for given_expected_result in expected_results_order:
                 result_expected = False
@@ -45,34 +51,48 @@ class Debiai_model:
                     if given_expected_result == expected_result["name"]:
                         result_expected = True
                 if not result_expected:
-                    raise ValueError("The given expected result '" + given_expected_result +
-                                     "' is not an expected result")
+                    raise ValueError(
+                        "The given expected result '"
+                        + given_expected_result
+                        + "' is not an expected result"
+                    )
         else:
-            expected_results_order = list(map(
-                lambda r: r["name"], self.project.expected_results))
+            expected_results_order = list(
+                map(lambda r: r["name"], self.project.expected_results)
+            )
 
         # Start the results verification
         sampleIndex = len(self.project.block_structure) - 1
 
         for rootBlock in results:
             self.__checkResultDict(
-                results[rootBlock], 0, sampleIndex, expected_results_order, str(rootBlock))
+                results[rootBlock],
+                0,
+                sampleIndex,
+                expected_results_order,
+                str(rootBlock),
+            )
 
         # Upload the results
-        return utils.post_model_results_dict(self.project.backend_url, self.project.id, self.id, results, expected_results_order)
+        return utils.post_model_results_dict(
+            self.project.debiai_url,
+            self.project.id,
+            self.id,
+            results,
+            expected_results_order,
+        )
 
     def add_results_df(self, results: pd.DataFrame, map_id=None) -> bool:
         """
         Add results from a dataFrame.
         """
         # Add results with __add_results_pd sequentialy
-        p_bar = utils.progress_bar(
-            'Adding results', results.shape[0], self.name)
+        p_bar = utils.progress_bar("Adding results", results.shape[0], self.name)
         results_added = 0
 
         chunk_size = 5000
         for start in range(0, results.shape[0], chunk_size):
-            results_subset = results.iloc[start:start + chunk_size]
+            results_subset = results.iloc[start : start + chunk_size]
 
             self.__add_results_pd(results_subset, map_id=map_id)
 
@@ -82,16 +102,16 @@ class Debiai_model:
         return True
 
     def __add_results_pd(self, results: pd.DataFrame, map_id=None) -> bool:
-        """ Add results to the model throught DataFrame """
+        """Add results to the model throught DataFrame"""
         if self.project.expected_results is None:
             raise ValueError(
-                "The project expected results need to be specified before adding results")
+                "The project expected results need to be specified before adding results"
+            )
 
         # Check if block names are in df columns.
         for block in self.project.block_structure:
             if block["name"] not in results.columns and block["name"] != map_id:
-                print("'" + block["name"] +
-                      "' is missing from the given samples")
+                print("'" + block["name"] + "' is missing from the given samples")
                 return False
 
         # Dataframe form
@@ -129,7 +149,7 @@ class Debiai_model:
             # Sample level
             # Exctract results
 
-            df_results_dict = df.to_dict('records')
+            df_results_dict = df.to_dict("records")
 
             # df_results_dict records :
             # [
@@ -138,18 +158,18 @@ class Debiai_model:
             # ]
 
             for record in df_results_dict:
-                dictRet[record[blockLevel['name']]] = []
+                dictRet[record[blockLevel["name"]]] = []
                 for resName in results_name:
-                    dictRet[record[blockLevel['name']]].append(
-                        record[resName])
+                    dictRet[record[blockLevel["name"]]].append(record[resName])
 
         else:
             # Other levels
-            dfs = dict(tuple(df.groupby(blockLevel['name'])))
+            dfs = dict(tuple(df.groupby(blockLevel["name"])))
 
             for key in dfs:
                 dictRet[key] = self.__pd_to_dict_recur(
-                    dfs[key], level + 1, results_name)
+                    dfs[key], level + 1, results_name
+                )
 
         return dictRet
 
@@ -163,7 +183,14 @@ class Debiai_model:
         self.add_results_df(df)
         return True
 
-    def __checkResultDict(self, block, level: int, sampleIndex: int, expected_results_order: List[str], path: str):
+    def __checkResultDict(
+        self,
+        block,
+        level: int,
+        sampleIndex: int,
+        expected_results_order: List[str],
+        path: str,
+    ):
         """
         Check recursively if a result dict is coherent with the block_structure
         """
@@ -171,8 +198,15 @@ class Debiai_model:
         if level == sampleIndex:
             #  Sample level : the results : they need to be verified
             if len(block) != len(expected_results_order):
-                raise ValueError("in : " + path + ", " +
-                                 str(len(block)) + " value where given but " + str(len(expected_results_order)) + "where expected")
+                raise ValueError(
+                    "in : "
+                    + path
+                    + ", "
+                    + str(len(block))
+                    + " value where given but "
+                    + str(len(expected_results_order))
+                    + "where expected"
+                )
 
         else:
             for subBlockKey in block:
@@ -181,16 +215,19 @@ class Debiai_model:
                     level + 1,
                     sampleIndex,
                     expected_results_order,
-                    path + " / " + str(subBlockKey)
+                    path + " / " + str(subBlockKey),
                 )
 
-    def add_results_hash(self, results: dict, expected_results_order: List[str] = []) -> dict:
+    def add_results_hash(
+        self, results: dict, expected_results_order: List[str] = []
+    ) -> dict:
         """
         Add results from a dict oh hash:results
         """
         if self.project.expected_results is None:
             raise ValueError(
-                "The project expected results need to be specified before adding results")
+                "The project expected results need to be specified before adding results"
+            )
 
         # Get wrong hash
         hash_list = []
@@ -199,7 +236,8 @@ class Debiai_model:
             hash_list.append(key)
 
         wrong_hash = utils.check_hash_exist(
-            self.project.backend_url, self.project.id, hash_list)
+            self.project.debiai_url, self.project.id, hash_list
+        )
 
         # Add expected results order
         if expected_results_order != []:
@@ -207,7 +245,8 @@ class Debiai_model:
                 new_results = []
                 for block in self.project.expected_results:
                     new_results.append(
-                        results[dic][expected_results_order.index(block["name"])])
+                        results[dic][expected_results_order.index(block["name"])]
+                    )
                 results[dic] = new_results
 
         # Remove wrong hash from the dico and add them to false dic to return
@@ -218,6 +257,7 @@ class Debiai_model:
 
         # Push new results in backend
         err = utils.post_results_hash(
-            self.project.backend_url, self.project.id, self.id, results)
+            self.project.debiai_url, self.project.id, self.id, results
+        )
 
         return wrong_values
